This project include some functions to get and store timetable for public transport in Moscow. 
Timetables are getting from the official cite: https://transport.mos.ru/. Results are parsing.
Project has function for calculating qualities of timetable and functions for storing and loading timetables from local database.
